## cdist-type__install_generate_fstab(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__install_generate_fstab - generate /etc/fstab during installation

## 2. DESCRIPTION

Generates a /etc/fstab file from information retreived from __install_mount definitions.

## 3. REQUIRED PARAMETERS

destination
  The path where to store the generated fstab file. Note that this is a path on the server, where cdist is running, not the target host.

## 4. OPTIONAL PARAMETERS

None.

## 5. BOOLEAN PARAMETERS

uuid
  use UUID instead of device in fstab

## 6. EXAMPLES

    __install_generate_fstab --destination /path/where/you/want/fstab
    __install_generate_fstab --uuid --destination /path/where/you/want/fstab

## 7. SEE ALSO

- cdist-type(7)

## 8. COPYING

Copyright (C) 2012 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).